GoogleCloudOrgpolicyV2CustomConstraint

Struct GoogleCloudOrgpolicyV2CustomConstraint 

pub struct GoogleCloudOrgpolicyV2CustomConstraint {
    pub action_type: Option<String>,
    pub condition: Option<String>,
    pub description: Option<String>,
    pub display_name: Option<String>,
    pub method_types: Option<Vec<String>>,
    pub name: Option<String>,
    pub resource_types: Option<Vec<String>>,
    pub update_time: Option<DateTime<Utc>>,
}
A custom constraint defined by customers which can only be applied to the given resource types and organization. By creating a custom constraint, customers can apply policies of this custom constraint. Creating a custom constraint itself does NOT apply any policy enforcement.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

action_type: Option<String>

Allow or deny type.

condition: Option<String>

A Common Expression Language (CEL) condition which is used in the evaluation of the constraint. For example: resource.instanceName.matches("(production|test)_(.+_)?[\d]+") or, resource.management.auto_upgrade == true The max length of the condition is 1000 characters.

description: Option<String>

Detailed information about this custom policy constraint. The max length of the description is 2000 characters.

display_name: Option<String>

One line display name for the UI. The max length of the display_name is 200 characters.

method_types: Option<Vec<String>>

All the operations being applied for this constraint.

name: Option<String>

Immutable. Name of the constraint. This is unique within the organization. Format of the name should be * organizations/{organization_id}/customConstraints/{custom_constraint_id} Example: organizations/123/customConstraints/custom.createOnlyE2TypeVms The max length is 70 characters and the minimum length is 1. Note that the prefix organizations/{organization_id}/customConstraints/ is not counted.

resource_types: Option<Vec<String>>

Immutable. The resource instance type on which this policy applies. Format will be of the form : / Example: * compute.googleapis.com/Instance.

update_time: Option<DateTime<Utc>>

Output only. The last time this custom constraint was updated. This represents the last time that the CreateCustomConstraint or UpdateCustomConstraint methods were called.